@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-from __future__ import print_function
 import sys
 import configargparse
 import ct.wrappedos
@@ -9,10 +7,7 @@ import ct.headerdeps
 
 def main(argv=None):
     cap = configargparse.getArgumentParser()
-    cap.add(
-        "filename",
-        help='File to use in "$CPP $CPPFLAGS -MM filename"',
-        nargs='+')
+    cap.add("filename", help='File to use in "$CPP $CPPFLAGS -MM filename"', nargs="+")
 
     # This will add the common arguments as a side effect
     ct.headerdeps.add_arguments(cap)
@@ -25,11 +20,11 @@ def main(argv=None):
             " Did you spell it correctly?  "
             "Another possible reason is that you didn't supply a filename and "
             "that configargparse has picked an unused positional argument from "
-            "the config file.\n".format(
-                args.filename[0]))
+            "the config file.\n".format(args.filename[0])
+        )
         return 1
 
-    results = set()
+    results = ct.utils.OrderedSet()
     for fname in args.filename:
         results |= hh.process(fname)
 
